@@ -40,9 +40,6 @@ class ISOBase:
     def get_fuel_mix_today(self):
         raise NotImplementedError()
 
-    def get_fuel_mix_yesterday(self):
-        raise NotImplementedError()
-
     def get_historical_fuel_mix(self, date):
         raise NotImplementedError()
 
@@ -52,10 +49,13 @@ class ISOBase:
     def get_demand_today(self):
         raise NotImplementedError()
 
-    def get_demand_yesterday(self):
+    def get_historical_demand(self, date):
         raise NotImplementedError()
 
-    def get_historical_demand(self, date):
+    def get_forecast_today(self):
+        raise NotImplementedError()
+
+    def get_historical_forecast(self, date):
         raise NotImplementedError()
 
     def get_latest_supply(self):
@@ -64,10 +64,13 @@ class ISOBase:
     def get_supply_today(self):
         raise NotImplementedError()
 
-    def get_supply_yesterday(self):
+    def get_historical_supply(self, date):
         raise NotImplementedError()
 
-    def get_historical_supply(self, date):
+    def get_battery_today(self):
+        raise NotImplementedError()
+
+    def get_historical_battery(self, date):
         raise NotImplementedError()
 
     def _latest_lmp_from_today(self, market, locations):
@@ -88,10 +91,6 @@ class ISOBase:
         today = pd.Timestamp.now(self.default_timezone).date()
         return method(today, *args, **kwargs)
 
-    def _yesterday_from_historical(self, method, *args, **kwargs):
-        yesterday = (pd.Timestamp.now(self.default_timezone) - pd.DateOffset(1)).date()
-        return method(yesterday, *args, **kwargs)
-
     def _supply_from_fuel_mix(self, date):
         df = self.get_historical_fuel_mix(date)
         supply_df = df.pop("Time").to_frame()
@@ -122,6 +121,11 @@ class GridStatus:
         if self.reserves is not None:
             s += "Reserves: %.0f %s" % (self.reserves, self.unit)
 
+        if self.notes and len(self.notes):
+            s += "Notes:\n"
+            for n in self.notes:
+                s += "-  %s\n" % n
+
         return s
 
 
