@@ -87,10 +87,6 @@ class ISONE(ISOBase):
         # todo should this use the latest endpoint?
         return self._today_from_historical(self.get_historical_fuel_mix)
 
-    def get_fuel_mix_yesterday(self):
-        "Get fuel mix for yesterday"
-        return self._yesterday_from_historical(self.get_historical_fuel_mix)
-
     def get_historical_fuel_mix(self, date):
         """Return fuel mix at a previous date
 
@@ -124,43 +120,21 @@ class ISONE(ISOBase):
     def get_demand_today(self):
         return self._today_from_historical(self.get_historical_demand)
 
-    def get_demand_yesterday(self):
-        return self._yesterday_from_historical(self.get_historical_demand)
-
     def get_historical_demand(self, date):
         """Return demand at a previous date in 5 minute intervals"""
         # todo document the earliest supported date
-        # _nstmp_formDate: 1659489137907
+        # supports a start and end date
         date = isodata.utils._handle_date(date)
+        date_str = date.strftime("%Y%m%d")
+        url = f"https://www.iso-ne.com/transform/csv/fiveminutesystemload?start={date_str}&end={date_str}"
+        data = _make_request(url, skiprows=[0, 1, 2, 3, 5])
 
-        date_str = date.strftime("%m/%d/%Y")
-        data = {
-            "_nstmp_startDate": date_str,
-            "_nstmp_endDate": date_str,
-            "_nstmp_twodays": False,
-            "_nstmp_twodaysCheckbox": False,
-            "_nstmp_requestType": "systemload",
-            "_nstmp_forecast": True,
-            "_nstmp_actual": True,
-            "_nstmp_cleared": True,
-            "_nstmp_priorDay": True,
-            "_nstmp_inclPumpLoad": True,
-            "_nstmp_inclBtmPv": True,
-        }
-
-        r = requests.post(
-            "https://www.iso-ne.com/ws/wsclient",
-            data=data,
-        ).json()
-
-        data = pd.DataFrame(r[0]["data"]["actual"])
-
-        data["BeginDate"] = pd.to_datetime(data["BeginDate"]).dt.tz_convert(
+        data["Date/Time"] = pd.to_datetime(data["Date/Time"]).dt.tz_localize(
             self.default_timezone,
         )
 
-        df = data[["BeginDate", "Mw"]].rename(
-            columns={"BeginDate": "Time", "Mw": "Demand"},
+        df = data[["Date/Time", "Native Load"]].rename(
+            columns={"Date/Time": "Time", "Native Load": "Demand"},
         )
 
         return df
@@ -173,14 +147,58 @@ class ISONE(ISOBase):
         "Get supply for today in MW"
         return self._today_from_historical(self.get_historical_supply)
 
-    def get_supply_yesterday(self):
-        "Get supply for yesterday in MW"
-        return self._yesterday_from_historical(self.get_historical_supply)
-
     def get_historical_supply(self, date):
         """Returns supply at a previous date in MW"""
         return self._supply_from_fuel_mix(date)
 
+    def get_forecast_today(self):
+        """Get load forecast for today in 1 hour intervals"""
+        d = self._today_from_historical(self.get_historical_forecast)
+        return d
+
+    def get_historical_forecast(self, date):
+        date = isodata.utils._handle_date(date)
+
+        start_str = date.strftime("%m/%d/%Y")
+        end_str = (date + pd.Timedelta(days=1)).strftime("%m/%d/%Y")
+        data = {
+            "_nstmp_startDate": start_str,
+            "_nstmp_endDate": end_str,
+            "_nstmp_twodays": True,
+            "_nstmp_twodaysCheckbox": False,
+            "_nstmp_requestType": "systemload",
+            "_nstmp_forecast": True,
+            "_nstmp_actual": False,
+            "_nstmp_cleared": False,
+            "_nstmp_priorDay": False,
+            "_nstmp_inclPumpLoad": True,
+            "_nstmp_inclBtmPv": True,
+        }
+
+        r = requests.post(
+            "https://www.iso-ne.com/ws/wsclient",
+            data=data,
+        ).json()
+
+        data = pd.DataFrame(r[0]["data"]["forecast"])
+
+        data["BeginDate"] = pd.to_datetime(data["BeginDate"]).dt.tz_convert(
+            self.default_timezone,
+        )
+        data["CreationDate"] = pd.to_datetime(data["CreationDate"]).dt.tz_convert(
+            self.default_timezone,
+        )
+
+        df = data[["CreationDate", "BeginDate", "Mw"]].rename(
+            columns={
+                "CreationDate": "Forecast Time",
+                "BeginDate": "Time",
+                "Mw": "Load Forecast",
+            },
+        )
+
+        return df
+
     def get_latest_lmp(self, market: str, locations: list = None):
         """
         Find Node ID mapping: https://www.iso-ne.com/markets-operations/settlements/pricing-node-tables/
@@ -223,15 +241,6 @@ class ISONE(ISOBase):
             include_id=include_id,
         )
 
-    def get_lmp_yesterday(self, market: str, locations: list = None, include_id=False):
-        "Get lmp for yesterday in 5 minute intervals"
-        return self._yesterday_from_historical(
-            self.get_historical_lmp,
-            market,
-            locations,
-            include_id=include_id,
-        )
-
     def get_historical_lmp(
         self,
         date,
@@ -285,12 +294,11 @@ class ISONE(ISOBase):
             if now.date() == date.date():
                 url = "https://www.iso-ne.com/transform/csv/fiveminlmp/currentrollinginterval"
                 print("Loading current interval")
+                # this request is very very slow for some reason. I suspect because the server is making the response dynamically
                 data_current = _make_request(url, skiprows=[0, 1, 2, 4])
-
                 data_current = data_current[
                     data_current["Local Time"] > data["Local Time"].max()
                 ]
-
                 data = pd.concat([data, data_current])
 
         elif market == Markets.REAL_TIME_HOURLY:
@@ -305,7 +313,9 @@ class ISONE(ISOBase):
                     + ":00"
                 )
             else:
-                raise RuntimeError("Today not support for hourly lmp")
+                raise RuntimeError(
+                    "Today not supported for hourly lmp. Try latest",
+                )
 
         elif market == Markets.DAY_AHEAD_HOURLY:
             url = f"https://www.iso-ne.com/static-transform/csv/histRpts/da-lmp/WW_DALMP_ISO_{date_str}.csv"
