@@ -25,9 +25,6 @@ class MISO(ISOBase):
         "ARKANSAS.HUB",
     ]
 
-    def __init__(self) -> None:
-        super().__init__()
-
     def get_latest_fuel_mix(self):
         url = self.BASE + "?messageType=getfuelmix&returnType=json"
         r = self._get_json(url)
@@ -63,8 +60,7 @@ class MISO(ISOBase):
         return self._latest_supply_from_fuel_mix()
 
     def get_demand_today(self):
-        url = "https://api.misoenergy.org/MISORTWDDataBroker/DataBrokerServices.asmx?messageType=gettotalload&returnType=json"
-        r = self._get_json(url)
+        r = self._get_load_and_forecast_data()
 
         date = pd.to_datetime(r["LoadInfo"]["RefId"].split(" ")[0])
 
@@ -81,11 +77,36 @@ class MISO(ISOBase):
         )
         df["Time"] = df["Time"].dt.tz_localize(self.default_timezone)
         df = df.rename(columns={"Value": "Demand"})
-
         df["Demand"] = pd.to_numeric(df["Demand"])
 
         return df
 
+    def get_forecast_today(self):
+        r = self._get_load_and_forecast_data()
+
+        date = pd.to_datetime(r["LoadInfo"]["RefId"].split(" ")[0]).tz_localize(
+            tz=self.default_timezone,
+        )
+
+        df = pd.DataFrame(
+            [x["Forecast"] for x in r["LoadInfo"]["MediumTermLoadForecast"]],
+        )
+
+        df["Time"] = date + pd.to_timedelta(df["HourEnding"].astype(int) - 1, "h")
+
+        df["Forecast Time"] = date
+
+        df = df[["Forecast Time", "Time", "LoadForecast"]].rename(
+            columns={"LoadForecast": "Load Forecast"},
+        )
+
+        return df
+
+    def _get_load_and_forecast_data(self):
+        url = "https://api.misoenergy.org/MISORTWDDataBroker/DataBrokerServices.asmx?messageType=gettotalload&returnType=json"
+        r = self._get_json(url)
+        return r
+
     def get_latest_lmp(self, market: str, locations: list = None):
         """
         Supported Markets:
@@ -130,7 +151,12 @@ class MISO(ISOBase):
         data["Time"] = time
         data["Market"] = market.value
         data["Location Type"] = "Pricing Node"
-        data.loc[data["Location"].str.endswith(".HUB"), "Location Type"] = "Hub"
+        data.loc[
+            data["Location"].str.endswith(
+                ".HUB",
+            ),
+            "Location Type",
+        ] = "Hub"
         data = data[
             [
                 "Time",
