@@ -26,6 +26,18 @@ def check_lmp_columns(df):
     # todo check if market is valid enum
 
 
+def check_forecast(df):
+    assert set(df.columns) == set(
+        ["Forecast Time", "Time", "Load Forecast"],
+    )
+
+
+def check_battery(df):
+    assert set(df.columns) == set(
+        ["Time", "Battery Supply"],
+    )
+
+
 def test_make_lmp_availability_df():
     isodata.utils.make_lmp_availability_table()
 
@@ -47,9 +59,6 @@ def test_get_fuel_mix(iso):
     df = iso.get_fuel_mix_today()
     assert isinstance(df, pd.DataFrame)
 
-    df = iso.get_fuel_mix_yesterday()
-    assert isinstance(df, pd.DataFrame)
-
 
 def test_list_isos():
     assert len(isodata.list_isos()) == 7
@@ -65,7 +74,7 @@ def test_get_iso_invalid():
         isodata.get_iso("ISO DOESNT EXIST")
 
 
-@pytest.mark.parametrize("iso", [NYISO(), ISONE(), CAISO(), Ercot()])
+@pytest.mark.parametrize("iso", [SPP(), NYISO(), ISONE(), CAISO(), Ercot()])
 def test_get_latest_status(iso):
     status = iso.get_latest_status()
     assert isinstance(status, GridStatus)
@@ -121,9 +130,6 @@ def test_get_supply_today(iso):
 
 @pytest.mark.parametrize("iso", [ISONE(), NYISO(), PJM(), CAISO()])
 def test_get_supply(iso):
-    df = iso.get_supply_yesterday()
-    assert isinstance(df, pd.DataFrame)
-
     date_str = "March 3, 2022"
     df = iso.get_historical_supply(date_str)
     assert isinstance(df, pd.DataFrame)
@@ -143,17 +149,6 @@ def test_get_demand_today(iso):
     assert df.loc[0]["Time"].tz is not None
 
 
-@pytest.mark.parametrize("iso", [PJM(), NYISO(), Ercot(), ISONE(), CAISO()])
-def test_get_demand_yesterday(iso):
-    # todo check that the date is right
-    df = iso.get_demand_yesterday()
-    assert isinstance(df, pd.DataFrame)
-    assert set(["Time", "Demand"]) == set(df.columns)
-    assert is_numeric_dtype(df["Demand"])
-    assert isinstance(df.loc[0]["Time"], pd.Timestamp)
-    assert df.loc[0]["Time"].tz is not None
-
-
 @pytest.mark.parametrize("iso", all_isos)
 def test_get_latest_demand(iso):
     demand = iso.get_latest_demand()
@@ -224,9 +219,6 @@ def test_get_historical_lmp(test):
         hist = iso.get_historical_lmp(date_str, m)
         assert isinstance(hist, pd.DataFrame)
         check_lmp_columns(hist)
-        yesterday = iso.get_lmp_yesterday(m)
-        assert isinstance(yesterday, pd.DataFrame)
-        check_lmp_columns(yesterday)
 
 
 @pytest.mark.parametrize(
@@ -303,3 +295,38 @@ def test_get_lmp_today(test):
         today = iso.get_lmp_today(m)
         assert isinstance(today, pd.DataFrame)
         check_lmp_columns(today)
+
+
+@pytest.mark.parametrize("iso", [ISONE(), CAISO(), NYISO()])
+def test_get_historical_forecast(iso):
+    test_date = (pd.Timestamp.now() - pd.Timedelta(days=14)).date()
+    forecast = iso.get_historical_forecast(test_date)
+    check_forecast(forecast)
+
+
+@pytest.mark.parametrize(
+    "iso",
+    [MISO(), SPP(), Ercot(), ISONE(), CAISO(), PJM(), NYISO()],
+)
+def test_get_forecast_today(iso):
+    forecast = iso.get_forecast_today()
+    check_forecast(forecast)
+
+
+@pytest.mark.parametrize(
+    "iso",
+    [CAISO()],
+)
+def test_get_battery_today(iso):
+    battery = iso.get_battery_today()
+    check_battery(battery)
+
+
+@pytest.mark.parametrize(
+    "iso",
+    [CAISO()],
+)
+def test_get_historical_battery(iso):
+    test_date = (pd.Timestamp.now() - pd.Timedelta(days=14)).date()
+    battery = iso.get_historical_battery(test_date)
+    check_battery(battery)
